@@ -1,5 +1,5 @@
-from creds import db
-from models import basic_user
+from .creds import db
+from .models import basic_user
 
 
 
