@@ -1,4 +1,4 @@
-from creds import db
+from .creds import db
 from .models import song_list, playlist, playlist_content
 from .song_interactions import find_song_by_id
 
