@@ -1,5 +1,5 @@
 from apscheduler.schedulers.background import BackgroundScheduler
-from dump_user import create_dump
+from .dump_user import create_dump
 
 scheduler = BackgroundScheduler()
 
